//////////////////////////////////////////////////////////////////////////////
//
// File:
//
//    Debug.c
//
// Purpose:
//
//    This file implements the serial functions to be used for debugging
//
//////////////////////////////////////////////////////////////////////////////

#include <visa.h>
#include <stdio.h>
#include "Debug.h"

// Utility function - not exported
ViStatus  	VISASerialConfig	(void);

//////////////////////////////////////////////////////////
//
// VISAInitSerial
//
// Initialize Serial port for debugging
//
//////////////////////////////////////////////////////////

static ViSession _SerialSession = VI_NULL;
static ViSession _rm = VI_NULL;

void VISASerialInit()
{
	ViStatus status = VI_SUCCESS;
	
	status = viOpenDefaultRM (&_rm);
	if(status)
	{	
		printf("VISASerialInit: Error Opening Default Resource Manager\n");
		VISASerialClose();
		return;
	}
		
	viOpen (_rm, "ASRL1::INSTR", VI_NULL, VI_NULL, &_SerialSession);
	if(status)
	{	
		printf("VISASerialInit: Error Opening Serial Port\n");
		VISASerialClose();
		return;
	}
	
	status = VISASerialConfig();
	if(status)
	{
		printf("VISASerialInit: Error Configuring Serial Port\n");
		VISASerialClose();
		return;
	}
	
	printf("Serial VISA initialized\r\n");
}
             
///////////////////////////////////////////////////////////
//
// VISASerialConfig
//
// Configure Serial Port for 115200, 8 bits, 1 stop, 
// no parity, no flow control.
//
//////////////////////////////////////////////////////////
ViStatus VISASerialConfig(void)
{				  

	ViStatus status = VI_SUCCESS;
	
	status = viSetAttribute (_SerialSession, VI_ATTR_ASRL_BAUD, 115200);
	if(status)
		return status;
		
	status = viSetAttribute (_SerialSession, VI_ATTR_ASRL_DATA_BITS, 8);
	if(status)
		return status;
		
	status = viSetAttribute (_SerialSession, VI_ATTR_ASRL_PARITY,
							 VI_ASRL_PAR_NONE);
	if(status)
		return status;
		
	status = viSetAttribute (_SerialSession, VI_ATTR_ASRL_STOP_BITS,
							 VI_ASRL_STOP_ONE);
	if(status)
		return status;
	
	status = viSetAttribute (_SerialSession, VI_ATTR_ASRL_FLOW_CNTRL,
							 VI_ASRL_FLOW_NONE);
	if(status)
		return status;
		
	return status;

}

//////////////////////////////////////////////////////////////
//
// VISAPrintToSerial
//
// Like printf but sends the formatted string to the serial port
//
/////////////////////////////////////////////////////////////
void VISAPrintToSerial(const char * pFormat, ...)
{

	ViStatus status;
    
   	va_list _ArgumentList;

   	va_start (_ArgumentList, pFormat);
    
   	status = viVPrintf(_SerialSession, (ViString)pFormat, _ArgumentList);
   	if(status)
   	{	
		printf("VISAPrintToSerial: Error Writing to port %X\n", status);
		VISASerialClose();
		return;
	}
    
    va_end (_ArgumentList);

    return;
}

//////////////////////////////////////////////////////////////
//
// VISASerialClose
//
// Close Serial Session and Default Resource Manager if 
// initialized
//
//////////////////////////////////////////////////////////////
void VISASerialClose(void)
{

	if(_SerialSession != VI_NULL)
		viClose (_SerialSession);
  
  	if(_rm != VI_NULL)
  		viClose(_rm);
  		
  	return;
}
  	
 
